#[repr(transparent)]pub struct Hpcr(pub u32);Expand description
SNVS_HP Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Hpcr
impl Hpcr
Sourcepub const fn set_rtc_en(&mut self, val: bool)
pub const fn set_rtc_en(&mut self, val: bool)
HP Real Time Counter Enable
Sourcepub const fn hpta_en(&self) -> bool
pub const fn hpta_en(&self) -> bool
HP Time Alarm Enable When set, the time alarm interrupt is generated if the value in the HP Time Alarm Registers is equal to the value of the HP Real Time Counter
Sourcepub const fn set_hpta_en(&mut self, val: bool)
pub const fn set_hpta_en(&mut self, val: bool)
HP Time Alarm Enable When set, the time alarm interrupt is generated if the value in the HP Time Alarm Registers is equal to the value of the HP Real Time Counter
Sourcepub const fn set_dis_pi(&mut self, val: DisPi)
pub const fn set_dis_pi(&mut self, val: DisPi)
Disable periodic interrupt in the functional interrupt
Sourcepub const fn pi_en(&self) -> bool
pub const fn pi_en(&self) -> bool
HP Periodic Interrupt Enable The periodic interrupt can be generated only if the HP Real Time Counter is enabled
Sourcepub const fn set_pi_en(&mut self, val: bool)
pub const fn set_pi_en(&mut self, val: bool)
HP Periodic Interrupt Enable The periodic interrupt can be generated only if the HP Real Time Counter is enabled
Sourcepub const fn pi_freq(&self) -> PiFreq
pub const fn pi_freq(&self) -> PiFreq
Periodic Interrupt Frequency Defines frequency of the periodic interrupt
Sourcepub const fn set_pi_freq(&mut self, val: PiFreq)
pub const fn set_pi_freq(&mut self, val: PiFreq)
Periodic Interrupt Frequency Defines frequency of the periodic interrupt
Sourcepub const fn hpcalb_en(&self) -> bool
pub const fn hpcalb_en(&self) -> bool
HP Real Time Counter Calibration Enabled Indicates that the time calibration mechanism is enabled.
Sourcepub const fn set_hpcalb_en(&mut self, val: bool)
pub const fn set_hpcalb_en(&mut self, val: bool)
HP Real Time Counter Calibration Enabled Indicates that the time calibration mechanism is enabled.
Sourcepub const fn hpcalb_val(&self) -> HpcalbVal
pub const fn hpcalb_val(&self) -> HpcalbVal
HP Calibration Value Defines signed calibration value for the HP Real Time Counter
Sourcepub const fn set_hpcalb_val(&mut self, val: HpcalbVal)
pub const fn set_hpcalb_val(&mut self, val: HpcalbVal)
HP Calibration Value Defines signed calibration value for the HP Real Time Counter
Sourcepub const fn btn_config(&self) -> u8
pub const fn btn_config(&self) -> u8
Button Configuration
Sourcepub const fn set_btn_config(&mut self, val: u8)
pub const fn set_btn_config(&mut self, val: u8)
Button Configuration
Sourcepub const fn set_btn_mask(&mut self, val: bool)
pub const fn set_btn_mask(&mut self, val: bool)
Button interrupt mask