nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Hphacivr

Struct Hphacivr 

#[repr(transparent)]
pub struct Hphacivr(pub u32);
SNVS_HP High Assurance Counter IV Register

Tuple Fields

0: u32

Implementations

Source

impl Hphacivr

pub const fn hac_counter_iv(&self) -> u32

High Assurance Counter Initial Value This register is used to set the starting count value to the high assurance counter

pub const fn set_hac_counter_iv(&mut self, val: u32)

High Assurance Counter Initial Value This register is used to set the starting count value to the high assurance counter