#[repr(transparent)]pub struct Hphacr(pub u32);Expand description
SNVS_HP High Assurance Counter Register
Tuple Fields
0: u32Implementations
Sourceimpl Hphacr
impl Hphacr
Sourcepub const fn hac_counter(&self) -> u32
pub const fn hac_counter(&self) -> u32
High Assurance Counter When the HAC_EN bit is set and the SSM is in the soft fail state, this counter starts to count down with the system clock
Sourcepub const fn set_hac_counter(&mut self, val: u32)
pub const fn set_hac_counter(&mut self, val: u32)
High Assurance Counter When the HAC_EN bit is set and the SSM is in the soft fail state, this counter starts to count down with the system clock