nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Hpsicr

Struct Hpsicr 

#[repr(transparent)]
pub struct Hpsicr(pub u32);
SNVS_HP Security Interrupt Control Register

Tuple Fields

0: u32

Implementations

Source

impl Hpsicr

pub const fn sv0_en(&self) -> bool

Security Violation 0 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 0 security violation

pub const fn set_sv0_en(&mut self, val: bool)

Security Violation 0 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 0 security violation

pub const fn sv1_en(&self) -> bool

Security Violation 1 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 1 security violation

pub const fn set_sv1_en(&mut self, val: bool)

Security Violation 1 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 1 security violation

pub const fn sv2_en(&self) -> bool

Security Violation 2 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 2 security violation

pub const fn set_sv2_en(&mut self, val: bool)

Security Violation 2 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 2 security violation

pub const fn sv3_en(&self) -> bool

Security Violation 3 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 3 security violation

pub const fn set_sv3_en(&mut self, val: bool)

Security Violation 3 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 3 security violation

pub const fn sv4_en(&self) -> bool

Security Violation 4 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 4 security violation

pub const fn set_sv4_en(&mut self, val: bool)

Security Violation 4 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 4 security violation

pub const fn sv5_en(&self) -> bool

Security Violation 5 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 5 security violation

pub const fn set_sv5_en(&mut self, val: bool)

Security Violation 5 Interrupt Enable Setting this bit to 1 enables generation of the security interrupt to the host processor upon detection of the Security Violation 5 security violation

pub const fn lpsvi_en(&self) -> bool

LP Security Violation Interrupt Enable This bit enables generating of the security interrupt to the host processor upon security violation signal from the LP section

pub const fn set_lpsvi_en(&mut self, val: bool)

LP Security Violation Interrupt Enable This bit enables generating of the security interrupt to the host processor upon security violation signal from the LP section