nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Lpgpr0LegacyAlias

Struct Lpgpr0LegacyAlias 

#[repr(transparent)]
pub struct Lpgpr0LegacyAlias(pub u32);
SNVS_LP General Purpose Register 0 (legacy alias)

Tuple Fields

0: u32

Implementations

Source

impl Lpgpr0LegacyAlias

pub const fn gpr(&self) -> u32

General Purpose Register When GPR_SL or GPR_HL bit is set, the register cannot be programmed.

pub const fn set_gpr(&mut self, val: u32)

General Purpose Register When GPR_SL or GPR_HL bit is set, the register cannot be programmed.