nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

LpgprAlias

Struct LpgprAlias 

#[repr(transparent)]
pub struct LpgprAlias(pub u32);
SNVS_LP General Purpose Registers 0 .. 3

Tuple Fields

0: u32

Implementations

Source

impl LpgprAlias

pub const fn gpr(&self) -> u32

General Purpose Register When GPR_SL or GPR_HL bit is set, the register cannot be programmed.

pub const fn set_gpr(&mut self, val: u32)

General Purpose Register When GPR_SL or GPR_HL bit is set, the register cannot be programmed.