nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Lpsmcmr

Struct Lpsmcmr 

#[repr(transparent)]
pub struct Lpsmcmr(pub u32);
SNVS_LP Secure Monotonic Counter MSB Register

Tuple Fields

0: u32

Implementations

Source

impl Lpsmcmr

pub const fn mon_counter(&self) -> u16

Monotonic Counter most-significant 16 Bits Note that writing to this register does not change the value of this field to the value that was written

pub const fn set_mon_counter(&mut self, val: u16)

Monotonic Counter most-significant 16 Bits Note that writing to this register does not change the value of this field to the value that was written

pub const fn mc_era_bits(&self) -> u16

Monotonic Counter Era Bits These bits are inputs to the module and typically connect to fuses

pub const fn set_mc_era_bits(&mut self, val: u16)

Monotonic Counter Era Bits These bits are inputs to the module and typically connect to fuses