#[repr(transparent)]pub struct Lpsr(pub u32);Expand description
SNVS_LP Status Register
Tuple Fields
0: u32Implementations
Sourceimpl Lpsr
impl Lpsr
Sourcepub const fn esvd(&self) -> Esvd
pub const fn esvd(&self) -> Esvd
External Security Violation Detected Indicates that a security violation is detected on one of the HP security violation ports
Sourcepub const fn set_esvd(&mut self, val: Esvd)
pub const fn set_esvd(&mut self, val: Esvd)
External Security Violation Detected Indicates that a security violation is detected on one of the HP security violation ports
Sourcepub const fn set_eo(&mut self, val: Eo)
pub const fn set_eo(&mut self, val: Eo)
Emergency Off This bit is set when a power off is requested.
Sourcepub const fn spof(&self) -> Spof
pub const fn spof(&self) -> Spof
Set Power Off The SPO bit is set when the power button is pressed longer than the configured debounce time
Sourcepub const fn set_spof(&mut self, val: Spof)
pub const fn set_spof(&mut self, val: Spof)
Set Power Off The SPO bit is set when the power button is pressed longer than the configured debounce time
Sourcepub const fn spon(&self) -> Spon
pub const fn spon(&self) -> Spon
Set Power On The SPON bit is set when the set_pwr_on_irq interrupt is triggered, which happens when the power button is pressed longer than the configured debounce time
Sourcepub const fn set_spon(&mut self, val: Spon)
pub const fn set_spon(&mut self, val: Spon)
Set Power On The SPON bit is set when the set_pwr_on_irq interrupt is triggered, which happens when the power button is pressed longer than the configured debounce time
Sourcepub const fn lpns(&self) -> Lpns
pub const fn lpns(&self) -> Lpns
LP Section is Non-Secured Indicates that LP section was provisioned/programmed in the non-secure state
Sourcepub const fn set_lpns(&mut self, val: Lpns)
pub const fn set_lpns(&mut self, val: Lpns)
LP Section is Non-Secured Indicates that LP section was provisioned/programmed in the non-secure state