nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Lpzmkr

Struct Lpzmkr 

#[repr(transparent)]
pub struct Lpzmkr(pub u32);
SNVS_LP Zeroizable Master Key Register

Tuple Fields

0: u32

Implementations

Source

impl Lpzmkr

pub const fn zmk(&self) -> u32

Zeroizable Master Key Each of these registers contains 32 bits of the 256-bit ZMK value

pub const fn set_zmk(&mut self, val: u32)

Zeroizable Master Key Each of these registers contains 32 bits of the 256-bit ZMK value