#[repr(transparent)]pub struct Lpsecr(pub u32);Expand description
SNVS_LP Security Events Configuration Register
Tuple Fields
0: u32Implementations
Sourceimpl Lpsecr
impl Lpsecr
Sourcepub const fn srtcr_en(&self) -> bool
pub const fn srtcr_en(&self) -> bool
SRTC Rollover Enable When set, an SRTC rollover event generates an LP security violation.
Sourcepub const fn set_srtcr_en(&mut self, val: bool)
pub const fn set_srtcr_en(&mut self, val: bool)
SRTC Rollover Enable When set, an SRTC rollover event generates an LP security violation.
Sourcepub const fn mcr_en(&self) -> bool
pub const fn mcr_en(&self) -> bool
MC Rollover Enable When set, an MC Rollover event generates an LP security violation.
Sourcepub const fn set_mcr_en(&mut self, val: bool)
pub const fn set_mcr_en(&mut self, val: bool)
MC Rollover Enable When set, an MC Rollover event generates an LP security violation.
Sourcepub const fn pfd_observ(&self) -> bool
pub const fn pfd_observ(&self) -> bool
System Power Fail Detector (PFD) Observability Flop The asynchronous reset input of this flop is connected directly to the inverted output of the PFD analog circuitry (external to the SNVS block)
Sourcepub const fn set_pfd_observ(&mut self, val: bool)
pub const fn set_pfd_observ(&mut self, val: bool)
System Power Fail Detector (PFD) Observability Flop The asynchronous reset input of this flop is connected directly to the inverted output of the PFD analog circuitry (external to the SNVS block)
Sourcepub const fn por_observ(&self) -> bool
pub const fn por_observ(&self) -> bool
Power On Reset (POR) Observability Flop The asynchronous reset input of this flop is connected directly to the output of the POR analog circuitry (external to the SNVS
Sourcepub const fn set_por_observ(&mut self, val: bool)
pub const fn set_por_observ(&mut self, val: bool)
Power On Reset (POR) Observability Flop The asynchronous reset input of this flop is connected directly to the output of the POR analog circuitry (external to the SNVS
Sourcepub const fn ltdc(&self) -> u8
pub const fn ltdc(&self) -> u8
Low Temp Detect Configuration These configuration bits are wired as an output of the module.
Sourcepub const fn set_ltdc(&mut self, val: u8)
pub const fn set_ltdc(&mut self, val: u8)
Low Temp Detect Configuration These configuration bits are wired as an output of the module.
Sourcepub const fn htdc(&self) -> u8
pub const fn htdc(&self) -> u8
High Temperature Detect Configuration These configuration bits are wired as an output of the module
Sourcepub const fn set_htdc(&mut self, val: u8)
pub const fn set_htdc(&mut self, val: u8)
High Temperature Detect Configuration These configuration bits are wired as an output of the module
Sourcepub const fn vrc(&self) -> u8
pub const fn vrc(&self) -> u8
Voltage Reference Configuration These configuration bits are wired as an output of the module.
Sourcepub const fn set_vrc(&mut self, val: u8)
pub const fn set_vrc(&mut self, val: u8)
Voltage Reference Configuration These configuration bits are wired as an output of the module.