#[repr(transparent)]pub struct Lpsmcmr(pub u32);Expand description
SNVS_LP Secure Monotonic Counter MSB Register
Tuple Fields
0: u32Implementations
Sourceimpl Lpsmcmr
impl Lpsmcmr
Sourcepub const fn mon_counter(&self) -> u16
pub const fn mon_counter(&self) -> u16
Monotonic Counter most-significant 16 Bits Note that writing to this register does not change the value of this field to the value that was written
Sourcepub const fn set_mon_counter(&mut self, val: u16)
pub const fn set_mon_counter(&mut self, val: u16)
Monotonic Counter most-significant 16 Bits Note that writing to this register does not change the value of this field to the value that was written
Sourcepub const fn mc_era_bits(&self) -> u16
pub const fn mc_era_bits(&self) -> u16
Monotonic Counter Era Bits These bits are inputs to the module and typically connect to fuses
Sourcepub const fn set_mc_era_bits(&mut self, val: u16)
pub const fn set_mc_era_bits(&mut self, val: u16)
Monotonic Counter Era Bits These bits are inputs to the module and typically connect to fuses